package com.gmei

import java.io.Serializable

import com.gmei.WeafareStat.{defaultParams, parser}
import org.apache.spark.sql.{SaveMode, TiContext}
import org.apache.log4j.{Level, Logger}
import scopt.OptionParser
import com.gmei.lib.AbstractParams
import com.gmei.GmeiConfig.{writeToJDBCTable,getMinusNDate}

object testt {

  Logger.getLogger("org.apache.spark").setLevel(Level.WARN)
  Logger.getLogger("org.apache.eclipse.jetty.server").setLevel(Level.OFF)

  case class Params(env: String = "dev"
                   ) extends AbstractParams[Params] with Serializable

  val defaultParams = Params()

  val parser = new OptionParser[Params]("Feed_EDA") {
    head("WeafareStat")
    opt[String]("env")
      .text(s"the databases environment you used")
      .action((x, c) => c.copy(env = x))
    note(
      """
        |For example, the following command runs this app on a tidb dataset:
        |
        | spark-submit --class com.gmei.WeafareStat ./target/scala-2.11/feededa-assembly-0.1.jar \
      """.stripMargin +
        s"|   --env ${defaultParams.env}"
    )
  }

  def main(args: Array[String]): Unit = {
    parser.parse(args, defaultParams).map { param =>
      GmeiConfig.setup(param.env)
      val spark_env = GmeiConfig.getSparkSession()
      val sc = spark_env._2

      val ti = new TiContext(sc)
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "diary_video")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "data_feed_click")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "blacklist")
      ti.tidbMapTable(dbName = "jerry_test", tableName = "bl_device_list")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "data_feed_exposure")


      val view_count = sc.sql(
          s"""
             |select params["business_id"] as diary_id,sum(params["out"]-params["in"]) as dur_time,count(cl_id) as num_clk
             |from online.tl_hdfs_maidian_view
             |where action="page_view"
             |and params["page_name"]="diary_detail"
             |and (params["out"]-params["in"])<3600
             |and partition_date >='20180801'
             |group by diary_id
         """.stripMargin
        )
      view_count.show()
      view_count.createOrReplaceTempView("temp")

      val avg = sc.sql(
        s"""
           |select diary_id,dur_time,num_clk,(dur_time/num_clk) as avg
           |from temp
           |order by num_clk desc
         """.stripMargin
      )
      GmeiConfig.writeToJDBCTable(avg, "avg", SaveMode.Overwrite)


      val result = avg
      result.show()



      }




    }


}
